diff --git a/src/test/subscription/t/032_subscribe_use_index.pl b/src/test/subscription/t/032_subscribe_use_index.pl
index 71e5be93ff..6c82919606 100644
--- a/src/test/subscription/t/032_subscribe_use_index.pl
+++ b/src/test/subscription/t/032_subscribe_use_index.pl
@@ -1,6 +1,6 @@
 # Copyright (c) 2022-2023, PostgreSQL Global Development Group
 
-# Test logical replication behavior with subscriber uses available index
+# Test logical replication behavior with subscriber using available index
 use strict;
 use warnings;
 use PostgreSQL::Test::Cluster;
@@ -15,8 +15,6 @@ $node_publisher->start;
 # create subscriber node
 my $node_subscriber = PostgreSQL::Test::Cluster->new('subscriber');
 $node_subscriber->init(allows_streaming => 'logical');
-$node_subscriber->append_conf('postgresql.conf',
-	"wal_retrieve_retry_interval = 1ms");
 $node_subscriber->start;
 
 my $publisher_connstr = $node_publisher->connstr . ' dbname=postgres';
@@ -39,7 +37,7 @@ $node_subscriber->safe_psql('postgres',
 
 # insert some initial data within the range 0-9 for x and y
 $node_publisher->safe_psql('postgres',
-	"INSERT INTO test_replica_id_full SELECT (i%10), (i%10)::text FROM generate_series(0,30)i;"
+	"INSERT INTO test_replica_id_full SELECT (i%10), (i%10)::text FROM generate_series(0,10)i;"
 );
 
 # create pub/sub
@@ -52,59 +50,30 @@ $node_subscriber->safe_psql('postgres',
 # wait for initial table synchronization to finish
 $node_subscriber->wait_for_subscription_sync($node_publisher, $appname);
 
-# delete 6 rows
+# delete 2 rows
 $node_publisher->safe_psql('postgres',
 	"DELETE FROM test_replica_id_full WHERE x IN (5, 6);");
 
-# update 6 rows
+# update 2 rows
 $node_publisher->safe_psql('postgres',
 	"UPDATE test_replica_id_full SET x = 100, y = '200' WHERE x IN (1, 2);");
 
 # wait until the index is used on the subscriber
 $node_publisher->wait_for_catchup($appname);
 $node_subscriber->poll_query_until(
-	'postgres', q{select (idx_scan = 12) from pg_stat_all_indexes where indexrelname = 'test_replica_id_full_idx';}
-) or die "Timed out while waiting for check subscriber tap_sub_rep_full updates 20 rows via index";
-
-# subscriber gets the missing table information
-$node_subscriber->safe_psql('postgres',
-	"ALTER SUBSCRIPTION tap_sub_rep_full REFRESH PUBLICATION");
-$node_subscriber->wait_for_subscription_sync($node_publisher, $appname);
-
-# delete 6 rows
-$node_publisher->safe_psql('postgres',
-	"DELETE FROM test_replica_id_full WHERE x IN (7, 8);");
-
-# update 6 rows
-$node_publisher->safe_psql('postgres',
-	"UPDATE test_replica_id_full SET x = 101, y = '201' WHERE x IN (3, 4);");
-
-# wait until the index is used on the subscriber
-$node_publisher->wait_for_catchup($appname);
-$node_subscriber->poll_query_until(
-	'postgres', q{select (idx_scan = 24) from pg_stat_all_indexes where indexrelname = 'test_replica_id_full_idx';}
-) or die "Timed out while waiting for check subscriber tap_sub_rep_full updates 20 rows via index";
+	'postgres', q{select (idx_scan = 4) from pg_stat_all_indexes where indexrelname = 'test_replica_id_full_idx';}
+) or die "Timed out while waiting for check subscriber tap_sub_rep_full updates 4 rows via index";
 
 # make sure that the subscriber has the correct data after the update UPDATE
 $result = $node_subscriber->safe_psql('postgres',
 	"select count(*) from test_replica_id_full WHERE (x = 100 and y = '200')");
-is($result, qq(6), 'ensure subscriber has the correct data at the end of the test');
+is($result, qq(2), 'ensure subscriber has the correct data at the end of the test');
 
 # make sure that the subscriber has the correct data after the first DELETE
 $result = $node_subscriber->safe_psql('postgres',
 	"select count(*) from test_replica_id_full where x in (5, 6);");
 is($result, qq(0), 'ensure subscriber has the correct data at the end of the test');
 
-# make sure that the subscriber has the correct data after the second UPDATE
-$result = $node_subscriber->safe_psql('postgres',
-	"select count(*) from test_replica_id_full WHERE x = 101 and y = '201'");
-is($result, qq(6), 'ensure subscriber has the correct data at the end of the test');
-
-# make sure that the subscriber has the correct data after the second DELETE
-$result = $node_subscriber->safe_psql('postgres',
-	"select count(*) from test_replica_id_full where x in (7, 8);");
-is($result, qq(0), 'ensure subscriber has the correct data at the end of the test');
-
 # cleanup pub
 $node_publisher->safe_psql('postgres', "DROP PUBLICATION tap_pub_rep_full");
 $node_publisher->safe_psql('postgres', "DROP TABLE test_replica_id_full");
@@ -273,8 +242,7 @@ $node_subscriber->safe_psql('postgres', "DROP TABLE people");
 # =============================================================================
 
 # =============================================================================
-# Testcase start: SUBSCRIPTION CAN USE INDEXES WITH EXPRESSIONS AND COLUMNS,
-# ALSO DROPPING/RECREATING INDEXES WORKS JUST FINE
+# Testcase start: SUBSCRIPTION CAN USE INDEXES WITH EXPRESSIONS AND COLUMNS
 
 # create tables pub and sub
 $node_publisher->safe_psql('postgres',
@@ -323,27 +291,6 @@ $result = $node_subscriber->safe_psql('postgres',
 	"SELECT count(*) FROM people WHERE firstname = 'no-name';");
 is($result, qq(0), 'ensure subscriber has the correct data at the end of the test');
 
-# now, drop the index with the expression, and re-create index on column lastname
-$node_subscriber->safe_psql('postgres',
-	"DROP INDEX people_names");
-$node_subscriber->safe_psql('postgres',
-	"CREATE INDEX people_last_names ON people(lastname)");
-
-# delete 1 row
-$node_publisher->safe_psql('postgres',
-	"DELETE FROM people WHERE lastname = 'last_name_18';");
-
-# wait until the index is used on the subscriber
-$node_publisher->wait_for_catchup($appname);
-$node_subscriber->poll_query_until(
-	'postgres', q{select idx_scan=1 from pg_stat_all_indexes where indexrelname = 'people_last_names';}
-) or die "Timed out while waiting for check subscriber tap_sub_rep_full deletes 1 row via index scan on people_last_names";
-
-# make sure that the subscriber has the correct data
-$result = $node_subscriber->safe_psql('postgres',
-	"SELECT count(*) FROM people WHERE lastname = 'last_name_18';");
-is($result, qq(0), 'ensure subscriber has the correct data at the end of the test');
-
 # cleanup pub
 $node_publisher->safe_psql('postgres', "DROP PUBLICATION tap_pub_rep_full");
 $node_publisher->safe_psql('postgres', "DROP TABLE people");
@@ -351,8 +298,7 @@ $node_publisher->safe_psql('postgres', "DROP TABLE people");
 $node_subscriber->safe_psql('postgres', "DROP SUBSCRIPTION tap_sub_rep_full");
 $node_subscriber->safe_psql('postgres', "DROP TABLE people");
 
-# Testcase end: SUBSCRIPTION CAN USE INDEXES WITH EXPRESSIONS AND COLUMNS,
-# ALSO DROPPING/RECREATING INDEXES WORKS JUST FINE
+# Testcase end: SUBSCRIPTION CAN USE INDEXES WITH EXPRESSIONS AND COLUMNS
 # =============================================================================
 
 # =============================================================================
@@ -406,31 +352,6 @@ $result = $node_subscriber->safe_psql('postgres',
 	"select count(*) from test_replica_id_full WHERE y IS NULL;");
 is($result, qq(3), 'ensure subscriber has the correct data at the end of the test');
 
-# drop the old index and create a new one on the other column
-$result = $node_subscriber->safe_psql('postgres',
-	"DROP INDEX test_replica_id_full_idx;");
-$node_subscriber->safe_psql('postgres',
-	"CREATE INDEX test_replica_id_full_idy ON test_replica_id_full(y)");
-
-# insert some initial data
-$node_publisher->safe_psql('postgres',
-	"TRUNCATE test_replica_id_full;");
-$node_publisher->safe_psql('postgres',
-	"INSERT INTO test_replica_id_full SELECT i FROM generate_series(0,21)i;");
-
-# now, we update only 1 row on the publisher and expect
-# the subscriber to only update 1 row via sequential scan
-# as the leftmost column of the index does not exist on the pub
-$node_publisher->safe_psql('postgres',
-	"UPDATE test_replica_id_full SET x = x + 1 WHERE x = 15;");
-
-$node_publisher->wait_for_catchup($appname);
-
-# make sure that the subscriber has the correct data
-$result = $node_subscriber->safe_psql('postgres',
-	"SELECT sum(x) FROM test_replica_id_full");
-is($result, qq(232), 'ensure subscriber has the correct data at the end of the test');
-
 # cleanup pub
 $node_publisher->safe_psql('postgres', "DROP PUBLICATION tap_pub_rep_full");
 $node_publisher->safe_psql('postgres', "DROP TABLE test_replica_id_full");
